#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>

#include "autofs_ismountpoint.h"

/*
 * Assumes autofs setup
 * /etc/auto.master:
 * /test	auto.indirect
 * /-		auto.direct
 *
 * /etc/auto.indirect
 * # Non-existent export
 * autofs	<some server>:/autofs
 * # Valid automount
 * Public       <some server>:/Public
 *
 * /etc/auto.direct
 * # Non-existent export
 * /dtest/s1	-nfsvers=3,tcp <some server>:/autofs
 * # Valid automount
 * /dtest/s2    -nfsvers=3,tcp <some server>:/Public
 */

void check_path(char *path)
{
	int ret, err; 

	ret = autofs_ismountpoint(path);

	err = AUTOFS_ISMOUNTPOINT_ISERR(ret);
	if (err) {
		switch (err) {
		case AUTOFS_ISMOUNTPOINT_ERR_PATH:
			printf("check_path: %s: bad path arg\n", path);
			break;
		case AUTOFS_ISMOUNTPOINT_ERR_FD:
			printf("check_path: %s: could not open misc device fd\n",
				path);
			break;
		case AUTOFS_ISMOUNTPOINT_ERR_ALLOC:
			printf("check_path: %s: could not alloc params\n",
				path);
			break;
		case AUTOFS_ISMOUNTPOINT_ERR_IOCTL:
			printf("check_path: %s: ioctl failed: %s\n",
				path, strerror(errno));
			break;
		default:
			printf("check_path: %s: error: %s\n",
				path, strerror(errno));
		}
		return;
	}

	if (ret == AUTOFS_ISMOUNTPOINT_NOT_AUTOFS) {
		printf("%s is not a mountpount\n", path);
		printf("%s is not contained in an autofs mount\n", path);
	} else {
		printf("%s is a mountpoint\n", path);
		if (ret & AUTOFS_ISMOUNTPOINT_AUTOFS)
			printf("%s is or is contained in an autofs fs\n", path);
		if (ret & AUTOFS_ISMOUNTPOINT_OTHER)
			printf("%s is an automounted mount point of fs other than autofs\n",
				path);
	}
}

int main(int argc, char **argv)
{
	char *path1 = "/test";
	char *path2 = "/test/Public";
	char *path3 = "/test/autofs";
	char *path4 = "/test/.hidden";
	char *path5 = "/dtest/s1";
	char *path6 = "/dtest/s1/.hidden";
	char *path7 = "/dtest/s2";
	char *path8 = "/dtest/s2/.hidden";

	check_path(path1);
	check_path(path2);
	check_path(path3);
	check_path(path4);
	check_path(path5);
	check_path(path6);
	check_path(path7);
	check_path(path8);
}
